@@ -4,7 +4,7 @@ from sqlalchemy import (
     Text,
     )
 
-from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.ext.declarative import declarative_base, DeclarativeMeta
 
 from sqlalchemy.orm import (
     scoped_session,
@@ -12,10 +12,18 @@ from sqlalchemy.orm import (
     )
 
 from zope.sqlalchemy import ZopeTransactionExtension
-from .. import project_package
+from .. import project_package, APP_NAME
 
 DBSession = project_package.models.models.DBSession
-Base = declarative_base()
+
+class RenameTables(DeclarativeMeta): 
+    def __init__(cls, classname, bases, dict_): 
+        if '__tablename__' in dict_: 
+            cls.__tablename__ = dict_['__tablename__'] = APP_NAME + "_" + cls.__tablename__ 
+        
+        return DeclarativeMeta.__init__(cls, classname, bases, dict_)
+
+Base = declarative_base(metaclass=RenameTables)
 
 class Post(Base):
     __tablename__ = 'posts'
